@@ -432,7 +432,8 @@ testExternalPost ()
     }
   curl_multi_cleanup (multi);
   MHD_stop_daemon (d);
-  fprintf (stderr, "\n");
+  if (LOOPCOUNT >= 99)
+    fprintf (stderr, "\n");
   return 0;
 }
 
@@ -470,7 +471,7 @@ main (int argc, char *const *argv)
   start_time = now();
   errorCount += testInternalPost ();
   fprintf (stderr,
-	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s" : "%s: Sequential POSTs (http/1.0) %f/s",
+	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s\n" : "%s: Sequential POSTs (http/1.0) %f/s\n",
 	   "internal select",
 	   (double) 1000 * LOOPCOUNT / (now() - start_time + 1.0));
   GAUGER ("internal select",
@@ -480,7 +481,7 @@ main (int argc, char *const *argv)
   start_time = now();
   errorCount += testMultithreadedPost ();
   fprintf (stderr,
-	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s" : "%s: Sequential POSTs (http/1.0) %f/s",
+	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s\n" : "%s: Sequential POSTs (http/1.0) %f/s\n",
 	   "multithreaded post",
 	   (double) 1000 * LOOPCOUNT / (now() - start_time + 1.0));
   GAUGER ("Multithreaded select",
@@ -490,7 +491,7 @@ main (int argc, char *const *argv)
   start_time = now();
   errorCount += testMultithreadedPoolPost ();
   fprintf (stderr,
-	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s" : "%s: Sequential POSTs (http/1.0) %f/s",
+	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s\n" : "%s: Sequential POSTs (http/1.0) %f/s\n",
 	   "thread with pool",
 	   (double) 1000 * LOOPCOUNT / (now() - start_time + 1.0));
   GAUGER ("thread with pool",
@@ -500,7 +501,7 @@ main (int argc, char *const *argv)
   start_time = now();
   errorCount += testExternalPost ();
   fprintf (stderr,
-	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s" : "%s: Sequential POSTs (http/1.0) %f/s",
+	   oneone ? "%s: Sequential POSTs (http/1.1) %f/s\n" : "%s: Sequential POSTs (http/1.0) %f/s\n",
 	   "external select",
 	   (double) 1000 * LOOPCOUNT / (now() - start_time + 1.0));
   GAUGER ("external select",
