@@ -24,7 +24,8 @@
  * @author Christian Grothoff
  */
 
-#include "config.h"
+#include "MHD_config.h"
+#include "platform.h"
 #include <curl/curl.h>
 #include <microhttpd.h>
 #include <stdlib.h>
@@ -71,7 +72,7 @@ post_iterator (void *cls,
                const char *filename,
                const char *content_type,
                const char *transfer_encoding,
-               const char *value, size_t off, size_t size)
+               const char *value, uint64_t off, size_t size)
 {
   int *eok = cls;
 
@@ -95,7 +96,7 @@ ahc_echo (void *cls,
           const char *url,
           const char *method,
           const char *version,
-          const char *upload_data, unsigned int *upload_data_size,
+          const char *upload_data, size_t *upload_data_size,
           void **unused)
 {
   static int eok;
@@ -119,9 +120,9 @@ ahc_echo (void *cls,
   MHD_post_process (pp, upload_data, *upload_data_size);
   if ((eok == 3) && (0 == *upload_data_size))
     {
-      response = MHD_create_response_from_data (strlen (url),
-                                                (void *) url,
-                                                MHD_NO, MHD_YES);
+      response = MHD_create_response_from_buffer (strlen (url),
+						  (void *) url,
+						  MHD_RESPMEM_MUST_COPY);
       ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
       MHD_destroy_response (response);
       MHD_destroy_post_processor (pp);
